#' @docType package
#' @name DatastreamDSWS2R
#' @title DatastreamDSWS2R
#' @description A package to manage access to the LSEG Datastream
#'  DSWS webservice
"_PACKAGE"
